==> moniwiki-1.0.7.tgz: moniwiki/wikismiley.php <==
<?php
# $Id: wikismiley.php,v 1.5 2003/08/17 13:47:42 wkpark Exp $
$smileys=array(
    "X-("=> array(16, 16, 0, "smile/x-(.gif"),
    ":D"=>  array(16, 16, 0, "smile/8-D.gif"),
    "&lt;:("=> array(16, 16, 0, "smile/(8(.gif"),
    ":o"=>  array(16, 16, 0, "smile/8-O.gif"),
    ":("=>  array(16, 16, 0, "smile/8-(.gif"),
    ":)"=>  array(16, 16, 0, "smile/8).gif"),
    ":-)"=> array(16, 16, 0, "smile/8-).gif"),
    "B)"=>  array(16, 16, 0, "smile/B-).gif"),
    ":))"=> array(16, 16, 0, "smile/8-)).gif"),
    ";)"=>  array(16, 16, 0, "smile/;-).gif"),
    ";|"=>  array(16, 16, 0, "smile/;-l.gif"),
    ":I"=>  array(16, 16, 0, "smile/8-I.gif"),
    ":|"=>  array(16, 16, 0, "smile/8-l.gif"),
    "|-|"=> array(16, 16, 0, "smile/l-l.gif"),
    "|-I"=> array(16, 16, 0, "smile/l-I.gif"),
    "/!\\"=>array(15, 15, 0, "alert.gif"),
    "\\?/"=>array(16, 16, 0, "icon-question.png"),
    "&lt;!>"=> array(15, 15, 0, "attention.gif"),
    "(!)"=> array(16, 16, 0, "idea.png"),

#    ":&"=>  array(16, 16, 0, "smile/8-%26.gif"),
    ":-X"=> array(16, 16, 0, "smile/8-x.gif"),
    ":-@"=> array(16, 16, 0, "smile/8-@.gif"),
    ":p"=> array(16, 16, 0, "smile/8-p.gif"),
    ":^)"=> array(16, 16, 0, "smile/8^).gif"),
    ":_)"=> array(16, 16, 0, "smile/8_).gif"),
#    ":v)"=> array(16, 16, 0, "smile/8v).gif"),
    ":*)"=> array(16, 16, 0, "smile/8star).gif"),
    "$-)"=> array(16, 16, 0, "smile/%24-).gif"),
    ":-$"=> array(16, 16, 0, "smile/8-%24.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
    ":-?"=> array(16, 16, 0, "smile/8-question.gif"),
#    ":\\"=> array(16, 16, 0, "smile/8-ll.gif"),
    ">:>"=> array(16, 16, 0, "smile/v8v.gif"),
    "%-)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%-6"=> array(16, 16, 0, "smile/%25-6.gif"),
#    "%-9"=> array(16, 16, 0, "smile/%25-9.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
    "B-)"=> array(16, 16, 0, "smile/B-).gif"),
#    ":'-)"=> array(16, 16, 0, "smile/8%27-).gif"),
#    ":'-("=>array(16, 16, 0, "smile/8%27-(.gif"),
    ":-S"=>array(16, 16, 0, "smile/8-S.gif"),
#    ":-Q"=>array(16, 16, 0, "smile/8-Q.gif"),
    ":->"=>array(16, 16, 0, "smile/8-v.gif"),
#    ":-]"=>array(16, 16, 0, "smile/8-].gif"),
#    "[:-)"=>array(16, 16, 0, "smile/[8-).gif"),
#    ":-["=>array(16, 16, 0, "smile/8-[.gif"),
#    ":-}"=>array(16, 16, 0, "smile/8-}.gif"),
#    "[:]"=>array(16, 16, 0, "smile/[8].gif"),
#    ":^)"=>array(16, 16, 0, "smile/8^).gif"),
#    ":v)"=>array(16, 16, 0, "smile/8).gif"),
    "@)"=>array(16, 16, 0, "smile/@-).gif"),
    "|)"=>array(16, 16, 0, "smile/l-l.gif"),
#    ":-|"=>array(16, 16, 0, "smile/8-l.gif"),
    "%-^"=>array(16, 16, 0, "smile/%25-^.gif"),
#    "(:)-)"=>array(16, 16, 0, "smile/(8)-).gif"),
#    ",-)"=>array(16, 16, 0, "smile/,-).gif"),
    "-_-"=>array(16, 16, 0, "smile/--.gif"),
    ";;"=>array(7, 16, 0, "smile/;;.gif"),
    "^^"=>array(16, 16, 0, "smile/^^.gif"),
#    "^8l"=>array(16, 16, 0, "smile/^8l.gif"),
#    "~8)"=>array(16, 16, 0, "smile/~8).gif"),
#    "=:-)"=>array(16, 16, 0, "smile/=8-).gif"),
#    "=:-O"=>array(16, 16, 0, "smile/=8O.gif"),
#    "=8-O"=>array(16, 16, 0, "smile/=88O.gif"),
#    ":v"=>array(16, 16, 0, "smile/8v.gif"),
#    ":-{}"=>array(16, 16, 0, "smile/8-{}.gif"),
    ":-9"=>array(16, 16, 0, "smile/8-9.gif"),
#    ":-||"=>array(16, 16, 0, "smile/8-lll.gif"),
#    ":-*"=>array(16, 16, 0, "smile/8-star.gif"),
#    ":-T"=>array(16, 16, 0, "smile/8-T.gif"),
#    "8>D"=>array(16, 16, 0, "smile/heart-D.gif"),
#    "%]["=>array(12, 16, 0, "smile/beer_r.gif"),
#    "][%"=>array(12, 16, 0, "smile/beer_l.gif"),

    # version 1.0
    "(./)"=>array(16, 16, 0, "checkbox.png"),
    "{OK}"=>array(12, 16, 0, "smile/thumb-up.gif"),
    "{NO}"=>array(12, 16, 0, "smile/thumb-down.gif"),
    "{X}"=>array(16, 16, 0, "icon-error.png"),
    "{i}"=>array(16, 16, 0, "icon-info.png"),
    "{1}"=>array(15, 13, 0, "prio1.gif"),
    "{2}"=>array(15, 13, 0, "prio2.gif"),
    "{3}"=>array(15, 13, 0, "prio3.gif"),
    "{da}"=>array(16, 16, 0, "da-16.png"),
    "{de}"=>array(16, 16, 0, "de-16.png"),
    "{en}"=>array(16, 16, 0, "en-16.png"),
    "{es}"=>array(16, 16, 0, "pt-16.png"),
    "{it}"=>array(16, 16, 0, "it-16.png"),
    "{ja}"=>array(16, 16, 0, "ja-16.png"),
    "{ko}"=>array(16, 16, 0, "ko-16.png"),
    "{nl}"=>array(16, 16, 0, "nl-16.png"),
    "{pt}"=>array(16, 16, 0, "pt-16.png"),
    "{sv}"=>array(16, 16, 0, "sv-16.png"),
    "{us}"=>array(16, 16, 0, "us-16.png"),
    "{zh}"=>array(16, 16, 0, "zh-16.png"),
);

?>

==> moniwiki-1.0.9.tgz: moniwiki/wikismiley.php <==
<?php
# $Id: wikismiley.php,v 1.7 2004/08/31 16:07:45 wkpark Exp $
$smileys=array(
    "X-("=> array(16, 16, 0, "smile/x-(.gif"),
    ":D"=>  array(16, 16, 0, "smile/8-D.gif"),
    "&lt;:("=> array(16, 16, 0, "smile/(8(.gif"),
    ":o"=>  array(16, 16, 0, "smile/8-O.gif"),
    ":("=>  array(16, 16, 0, "smile/8-(.gif"),
    ":)"=>  array(16, 16, 0, "smile/8).gif"),
    ":))"=> array(16, 16, 0, "smile/8-)).gif"),
    ":-("=> array(16, 16, 0, "smile/8-(.gif"),
    ":-)"=> array(16, 16, 0, "smile/8-).gif"),
    ":-))"=>array(16, 16, 0, "smile/8-)).gif"),
    ":-(=)"=>array(16, 16, 0, "smile/8-lll.gif"),
    "B)"=>  array(16, 16, 0, "smile/B-).gif"),
    "B-)"=> array(16, 16, 0, "smile/B-).gif"),
    ";)"=>  array(16, 16, 0, "smile/;-).gif"),
    ";-)"=> array(16, 16, 0, "smile/;-).gif"),
#    ";|"=>  array(16, 16, 0, "smile/;-l.gif"),
    ":I"=>  array(16, 16, 0, "smile/8-I.gif"),
    ":|"=>  array(16, 16, 0, "smile/8-l.gif"),
    "|)"=>  array(16, 16, 0, "smile/l-l.gif"),
    "|-)"=> array(16, 16, 0, "smile/l-l.gif"),
    "|-I"=> array(16, 16, 0, "smile/l-I.gif"),
    "/!\\"=>array(15, 15, 0, "smile/alert.gif"),
    "\\?/"=>array(16, 16, 0, "smile/icon-question.png"),
    "&lt;!>"=> array(15, 15, 0, "smile/attention.gif"),
    "(!)"=> array(16, 16, 0, "smile/idea.png"),

#    ":&"=>  array(16, 16, 0, "smile/8-%26.gif"),
    ":-X"=> array(16, 16, 0, "smile/8-x.gif"),
    ":-@"=> array(16, 16, 0, "smile/8-@.gif"),
    ":p"=>  array(16, 16, 0, "smile/8-p.gif"),
    ":^)"=> array(16, 16, 0, "smile/8^).gif"),
    ":_)"=> array(16, 16, 0, "smile/8_).gif"),
#    ":v)"=> array(16, 16, 0, "smile/8v).gif"),
    ":*)"=> array(16, 16, 0, "smile/8star).gif"),
    "$-)"=> array(16, 16, 0, "smile/%24-).gif"),
    ":-$"=> array(16, 16, 0, "smile/8-%24.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
    ":-?"=> array(16, 16, 0, "smile/8-question.gif"),
    ":\\"=> array(16, 16, 0, "smile/8-ll.gif"),
    ">:>"=> array(16, 16, 0, "smile/v8v.gif"),
    "%-)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%)"=> array(16, 16, 0, "smile/%25-).gif"),
#    "%-6"=> array(16, 16, 0, "smile/%25-6.gif"),
#    "%-9"=> array(16, 16, 0, "smile/%25-9.gif"),
#    "=)"=> array(16, 16, 0, "smile/=).gif"),
#    ":'-)"=> array(16, 16, 0, "smile/8%27-).gif"),
#    ":'-("=>array(16, 16, 0, "smile/8%27-(.gif"),
    ":-S"=>array(16, 16, 0, "smile/8-S.gif"),
#    ":-Q"=>array(16, 16, 0, "smile/8-Q.gif"),
    ":->"=>array(16, 16, 0, "smile/8-v.gif"),
#    ":-]"=>array(16, 16, 0, "smile/8-].gif"),
#    "[:-)"=>array(16, 16, 0, "smile/[8-).gif"),
#    ":-["=>array(16, 16, 0, "smile/8-[.gif"),
#    ":-}"=>array(16, 16, 0, "smile/8-}.gif"),
#    "[:]"=>array(16, 16, 0, "smile/[8].gif"),
#    ":^)"=>array(16, 16, 0, "smile/8^).gif"),
#    ":v)"=>array(16, 16, 0, "smile/8).gif"),
    "@)"=>array(16, 16, 0, "smile/@-).gif"),
#    ":-|"=>array(16, 16, 0, "smile/8-l.gif"),
    "%-^"=>array(16, 16, 0, "smile/%25-^.gif"),
#    "(:)-)"=>array(16, 16, 0, "smile/(8)-).gif"),
#    ",-)"=>array(16, 16, 0, "smile/,-).gif"),
    "-_-"=>array(16, 16, 0, "smile/--.gif"),
    ";;"=>array(7, 16, 0, "smile/;;.gif"),
    "^^"=>array(16, 16, 0, "smile/^^.gif"),
#    "^8l"=>array(16, 16, 0, "smile/^8l.gif"),
#    "~8)"=>array(16, 16, 0, "smile/~8).gif"),
#    "=:-)"=>array(16, 16, 0, "smile/=8-).gif"),
#    "=:-O"=>array(16, 16, 0, "smile/=8O.gif"),
#    "=8-O"=>array(16, 16, 0, "smile/=88O.gif"),
#    ":v"=>array(16, 16, 0, "smile/8v.gif"),
#    ":-{}"=>array(16, 16, 0, "smile/8-{}.gif"),
    ":-9"=>array(16, 16, 0, "smile/8-9.gif"),
#    ":-||"=>array(16, 16, 0, "smile/8-lll.gif"),
#    ":-*"=>array(16, 16, 0, "smile/8-star.gif"),
#    ":-T"=>array(16, 16, 0, "smile/8-T.gif"),
#    "8>D"=>array(16, 16, 0, "smile/heart-D.gif"),
#    "%]["=>array(12, 16, 0, "smile/beer_r.gif"),
#    "][%"=>array(12, 16, 0, "smile/beer_l.gif"),

    # version 1.0
    "(./)"=>array(16, 16, 0, "smile/checkbox.png"),
    "{OK}"=>array(12, 16, 0, "smile/thumb-up.gif"),
    "{NO}"=>array(12, 16, 0, "smile/thumb-down.gif"),
    "{X}"=>array(16, 16, 0, "smile/icon-error.png"),
    "{i}"=>array(16, 16, 0, "smile/icon-info.png"),
    "{1}"=>array(15, 13, 0, "smile/prio1.gif"),
    "{2}"=>array(15, 13, 0, "smile/prio2.gif"),
    "{3}"=>array(15, 13, 0, "smile/prio3.gif"),
    "{br}"=>array(16, 16, 0, "interwiki/br-16.png"),
    "{da}"=>array(16, 16, 0, "interwiki/da-16.png"),
    "{de}"=>array(16, 16, 0, "interwiki/de-16.png"),
    "{en}"=>array(16, 16, 0, "interwiki/en-16.png"),
    "{es}"=>array(16, 16, 0, "interwiki/es-16.png"),
    "{fi}"=>array(16, 16, 0, "interwiki/fi-16.png"),
    "{fr}"=>array(16, 16, 0, "interwiki/fr-16.png"),
    "{gr}"=>array(16, 16, 0, "interwiki/gr-16.png"),
    "{il}"=>array(16, 16, 0, "interwiki/il-16.png"),
    "{it}"=>array(16, 16, 0, "interwiki/it-16.png"),
    "{ja}"=>array(16, 16, 0, "interwiki/ja-16.png"),
    "{ko}"=>array(16, 16, 0, "interwiki/ko-16.png"),
    "{nl}"=>array(16, 16, 0, "interwiki/nl-16.png"),
    "{pt}"=>array(16, 16, 0, "interwiki/pt-16.png"),
    "{sv}"=>array(16, 16, 0, "interwiki/sv-16.png"),
    "{us}"=>array(16, 16, 0, "interwiki/us-16.png"),
    "{zh}"=>array(16, 16, 0, "interwiki/zh-16.png"),
);

?>
